yakumo.neutron.v2.vpn

Package yakumo :: Package neutron :: Package v2 :: Package vpn |
[hide private]
[frames] | no frames]

# Package vpn

source code

Submodules | [hide private]
yakumo.neutron.v2.vpn.ike_policy: Resource class and its manager for VPN IKE policies in Networking V2 API yakumo.neutron.v2.vpn.ipsec_policy: Resource class and its manager for VPN IPSec policies in Networking V2 API yakumo.neutron.v2.vpn.ipsec_site_connection: Resource class and its manager for VPN IPSec site connections in Networking V2 API yakumo.neutron.v2.vpn.service: Resource class and its manager for VPN services in Networking V2 API

Classes | [hide private]
| Client

Variables | [hide private]
| __package__ = ``'``yakumo.neutron.v2.vpn``'``